@@ -22,6 +22,7 @@
 #include "matchwidget_p.h"
 #include "matchwidget.h"
 #include "listview/grandsearchlistview.h"
+#include "viewmore/viewmorebutton.h"
 #include "utils/utils.h"
 #include "gui/datadefine.h"
 
@@ -80,25 +81,8 @@ void MatchWidget::appendMatchedData(const MatchedItemMap &matchedData)
             continue;
         }
 
-        // 网络搜索项时，对显示内容进行翻译处理
-        if (itData.key() == GRANDSEARCH_GROUP_WEB) {
-
-            MatchedItems webItems;
-            for (auto val : itData.value()) {
-                QString showItem = tr("Search for \"%1\"").arg(val.item);
-                val.name = showItem;
-                webItems.append(val);
-            }
-
-            // 追加匹配数据到类目列表中
-            groupWidget->appendMatchedItems(webItems, itData.key());
-
-            bNeedRelayout = true;
-
-        } else {
-            // 追加匹配数据到类目列表中
-            groupWidget->appendMatchedItems(itData.value(), itData.key());
-        }
+        // 追加匹配数据到类目列表中
+        groupWidget->appendMatchedItems(itData.value(), itData.key());
 
         // 列表中有数据，显示类目列表
         groupWidget->setVisible(groupWidget->itemCount() > 0);
@@ -171,9 +155,17 @@ void MatchWidget::selectNextItem()
         // 选择项在当前列表中
         GroupWidget *group = m_vGroupWidgets.at(i);
         GrandSearchListView *listView = group->getListView();
-        const QModelIndex &index = listView->currentIndex();
+        ViewMoreButton *viewMoreBtn = group->getViewMoreButton();
+
+        int nextRow = -1;
+        if (viewMoreBtn->isSelected()) {
+            nextRow = 0;
+            viewMoreBtn->setSelected(false);
+        } else {
+            const QModelIndex &index = listView->currentIndex();
+            nextRow = index.row() + 1;
+        }
 
-        int nextRow = index.row() + 1;
         const QModelIndex &nextIndex = listView->model()->index(nextRow, 0);
         if (nextIndex.isValid()) {
             listView->setCurrentIndex(nextIndex);
@@ -214,8 +206,9 @@ void MatchWidget::selectPreviousItem()
         // 选择项在当前列表中
         GroupWidget *group = m_vGroupWidgets.at(i);
         GrandSearchListView *listView = group->getListView();
-        const QModelIndex &index = listView->currentIndex();
+        ViewMoreButton *viewMoreBtn = group->getViewMoreButton();
 
+        const QModelIndex &index = listView->currentIndex();
         int previousRow = index.row() - 1;
         const QModelIndex &previousIndex = listView->model()->index(previousRow, 0);
         if (previousIndex.isValid()) {
@@ -223,6 +216,12 @@ void MatchWidget::selectPreviousItem()
             m_customSelected = true;
             currentIndexChanged(group->searchGroupName(), previousIndex);
             break;
+        } else if (viewMoreBtn->isVisible() && !viewMoreBtn->isSelected()) {
+            viewMoreBtn->setSelected(true);
+            listView->setCurrentIndex(QModelIndex());
+            currentIndexChanged(group->searchGroupName(), QModelIndex());
+            m_customSelected = true;
+            break;
         } else {
             // 选择项是当前列表的第一项，需要选择上一个列表的最后一项
             if (i > 0) {
@@ -230,6 +229,7 @@ void MatchWidget::selectPreviousItem()
                 if (Q_LIKELY(selected)) {
                     // 切换成功后，需要将当前列表选择为空
                     listView->setCurrentIndex(QModelIndex());
+                    viewMoreBtn->setSelected(false);
                     m_customSelected = true;
                 } else {
                     qWarning() << "select previous failed";
@@ -248,8 +248,16 @@ void MatchWidget::handleItem()
 {
     for (int i = 0; i < m_vGroupWidgets.count(); ++i) {
         if (hasSelectItem(i)) {
+            ViewMoreButton *viewMoreBtn = m_vGroupWidgets.at(i)->getViewMoreButton();
+            Q_ASSERT(viewMoreBtn);
             GrandSearchListView *listView = m_vGroupWidgets.at(i)->getListView();
             Q_ASSERT(listView);
+
+            if (viewMoreBtn->isSelected()) {
+                viewMoreBtn->click();
+                break;
+            }
+
             MatchedItem item = listView->currentIndex().data(DATA_ROLE).value<MatchedItem>();
             Utils::openMatchedItem(item);
             emit sigCloseWindow();
@@ -286,6 +294,10 @@ void MatchWidget::onSelectItemByMouse(const MatchedItem &item)
     if (listView) {
         for (int i = 0; i < m_vGroupWidgets.count(); ++i) {
             if (hasSelectItem(i)) {
+                ViewMoreButton *viewMoreBtn = m_vGroupWidgets.at(i)->getViewMoreButton();
+                Q_ASSERT(viewMoreBtn);
+                viewMoreBtn->setSelected(false);
+
                 GrandSearchListView *tmpListView = m_vGroupWidgets.at(i)->getListView();
                 Q_ASSERT(tmpListView);
                 if (listView != tmpListView) {
@@ -311,6 +323,15 @@ bool MatchWidget::selectFirstItem(int groupNumber)
         GroupWidget *group = m_vGroupWidgets.at(i);
         Q_ASSERT(group);
 
+        ViewMoreButton *viewMoreBtn = group->getViewMoreButton();
+        Q_ASSERT(viewMoreBtn);
+
+        if (viewMoreBtn->isVisible()) {
+            viewMoreBtn->setSelected(true);
+            currentIndexChanged(group->searchGroupName(), QModelIndex());
+            return true;
+        }
+
         GrandSearchListView *listView = group->getListView();
         Q_ASSERT(listView);
 
@@ -363,6 +384,13 @@ bool MatchWidget::hasSelectItem(int groupNumber)
     if (Q_UNLIKELY(!group))
         return false;
 
+    ViewMoreButton *viewMoreBtn = group->getViewMoreButton();
+    if (Q_UNLIKELY(!viewMoreBtn))
+        return false;
+
+    if (viewMoreBtn->isSelected())
+        return true;
+
     GrandSearchListView *listView = group->getListView();
     if (Q_UNLIKELY(!listView))
         return false;
@@ -380,9 +408,13 @@ void MatchWidget::clearSelectItem()
 
     for (int i = 0; i < m_vGroupWidgets.count(); ++i) {
         if (hasSelectItem(i)) {
+            ViewMoreButton *viewMoreBtn = m_vGroupWidgets.at(i)->getViewMoreButton();
+            Q_ASSERT(viewMoreBtn);
+
             GrandSearchListView *tmpListView = m_vGroupWidgets.at(i)->getListView();
             Q_ASSERT(tmpListView);
 
+            viewMoreBtn->setSelected(false);
             tmpListView->setCurrentIndex(QModelIndex());
             selectChanged = true;
         }
@@ -404,14 +436,17 @@ void MatchWidget::adjustScrollBar()
         if (Q_UNLIKELY((!group)))
             continue;
 
+        ViewMoreButton *viewMoreBtn = group->getViewMoreButton();
+        if (Q_UNLIKELY(!viewMoreBtn))
+            continue;
+
         GrandSearchListView* listView = group->getListView();
         if (Q_UNLIKELY(!listView))
             continue;
 
-        if (!listView->currentIndex().isValid()) {
+        if (!listView->currentIndex().isValid() && !viewMoreBtn->isSelected()) {
             nCurSelHeight += group->height();
-        }
-        else {
+        } else {
             nCurSelHeight += group->getCurSelectHeight();
             break;
         }
@@ -544,6 +579,7 @@ GroupWidget *MatchWidget::createGroupWidget(const QString &searchGroupName)
         groupWidget->setFocusPolicy(Qt::NoFocus);
 
         connect(groupWidget, &GroupWidget::showMore, this, &MatchWidget::reLayout);
+        connect(groupWidget, &GroupWidget::sigCurrentItemChanged, this, &MatchWidget::sigCurrentItemChanged);
 
         GrandSearchListView *listView = groupWidget->getListView();
         Q_ASSERT(listView);
