@@ -86,12 +86,8 @@ void ConfigWidget::initUI()
 
     m_searchGroupWidget = new ScopeWidget(m_scrollAreaContent);
     m_searchCustomWidget = new CustomWidget(m_scrollAreaContent);
-    m_searchPlanWidget = new PlanWidget(m_scrollAreaContent);
-    m_tailerWidget = new TailerWidget(m_scrollAreaContent);
     m_scrollLayout->addWidget(m_searchGroupWidget);
-    m_scrollLayout->addWidget(m_tailerWidget);
     m_scrollLayout->addWidget(m_searchCustomWidget);
-    m_scrollLayout->addWidget(m_searchPlanWidget);
     m_scrollLayout->addStretch();
 
     m_scrollArea->setWidget(m_scrollAreaContent);
