@@ -19,11 +19,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 extern "C" {
-#include <gio/gio.h>
-#include <gio/gdesktopappinfo.h>
 #include <ctype.h>
 }
 
+#include <gio/gio.h>
+#include <gio/gdesktopappinfo.h>
+
 #include "utils.h"
 
 #include "global/builtinsearch.h"
@@ -46,7 +47,6 @@ extern "C" {
 #include <QIcon>
 #include <QApplication>
 
-
 DCORE_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 DGUI_USE_NAMESPACE
@@ -898,11 +898,6 @@ bool Utils::openWithBrowser(const QString &words)
     if (words.isEmpty())
         return false;
 
-    static QString defaultUrl = "https://www.baidu.com/s?wd=%0&ie=UTF-8";
-
-    QString encodeString(QUrl::toPercentEncoding(words));
-    QString url = defaultUrl.arg(QString(encodeString));
-
     // 获取默认浏览器
     QString defaultDesktopFile = defaultBrowser();
     if (defaultDesktopFile.isEmpty()) {
@@ -911,7 +906,7 @@ bool Utils::openWithBrowser(const QString &words)
     }
     //默认浏览器
     qDebug() << "open with" << defaultDesktopFile;
-    return launchApp(defaultDesktopFile, {url});
+    return launchApp(defaultDesktopFile, {words});
 }
 
 QIcon Utils::defaultIcon(const MatchedItem &item)
