@@ -32,10 +32,18 @@
         <translation>Dəyişdirilmə vaxtı:</translation>
     </message>
 </context>
+<context>
+    <name>BestMatchWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="38"/>
+        <source>Best match</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>CustomWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="38"/>
+        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="42"/>
         <source>Custom search</source>
         <translation>başqa formada axtarış</translation>
     </message>
@@ -119,7 +127,7 @@
 <context>
     <name>GroupWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="254"/>
+        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="260"/>
         <source>More</source>
         <translation>Daha çox</translation>
     </message>
@@ -160,14 +168,6 @@
         <translation>Heç nə tapılmadı</translation>
     </message>
 </context>
-<context>
-    <name>MatchWidget</name>
-    <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="88"/>
-        <source>Search for &quot;%1&quot;</source>
-        <translation>&quot;%1&quot; axtarın</translation>
-    </message>
-</context>
 <context>
     <name>PlanWidget</name>
     <message>
@@ -181,27 +181,27 @@
         <translation>Axtarış təcrübəsi proqramına qoşulun</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="63"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
         <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
         <translation>Axtarış təcrübəsi proqramına qoşulmaq o deməkdir ki, siz bizə cihazınız, sisteminiz, fayl nişanları, tərkibləri və xüsusiyyətləri, tətbiqlər və onların tənzimləmələri haqqında məlumatları toplamağa icazə verirsiniz. Əgər siz yuxarıda göstərilən məlumatların bizim tərəfimizdən toplanmasını istəmirsinizsə bu proqrama qoşulmayın.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="71"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
         <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
         <translation>Məlumatlarınızın idarə edilməsi haqqında daha çox bilmək üçün, letfən UnionTech Proram Təminatı Məxfilik Siyasəti ilə buradan tanış olun (</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="75"/>
         <source>https://www.uniontech.com/agreement/privacy-en</source>
         <translation>https://www.uniontech.com/agreement/privacy-en</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="74"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
         <source>https://www.deepin.org/en/agreement/privacy/</source>
         <translation>https://www.deepin.org/en/agreement/privacy/</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="78"/>
         <source>).</source>
         <translation>).</translation>
     </message>
@@ -291,7 +291,7 @@
     <message>
         <location filename="../src/grand-search-daemon/searcher/file/filesearchutils.cpp" line="215"/>
         <source>modified</source>
-        <translation type="unfinished"/>
+        <translation>dəyişdirilib</translation>
     </message>
 </context>
 <context>
@@ -302,27 +302,83 @@
         <translation>Axtarış tərkibləri</translation>
     </message>
 </context>
+<context>
+    <name>SearchEngineWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="48"/>
+        <source>Default search engine</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="56"/>
+        <source>Search for keywords by the default search engine.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
+        <source>Default search engine is</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="81"/>
+        <source>Google</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="82"/>
+        <source>Baidu</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="83"/>
+        <source>Bing</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="84"/>
+        <source>Yahoo</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="85"/>
+        <source>360</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="86"/>
+        <source>Sogou</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>StaticTextWorker</name>
+    <message>
+        <location filename="../src/grand-search-daemon/searcher/web/statictextworker.cpp" line="67"/>
+        <source>Search for &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>TailerWidget</name>
     <message>
         <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="33"/>
         <source>Tailer settings</source>
-        <translation type="unfinished"/>
+        <translation>Kənar ayarlar</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="42"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
         <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
-        <translation type="unfinished"/>
+        <translation>Bu, təkrarlanan adlar ilə elemntlərin daha yaxşı müəyyənləşdirilməsi və fərqləndirilməsi üçün axatrış nəticələrinin sonunda göstrərilir.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="50"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="56"/>
         <source>Parent directory</source>
-        <translation type="unfinished"/>
+        <translation>Ana kataloq</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="52"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="58"/>
         <source>Time modified</source>
-        <translation type="unfinished"/>
+        <translation>Dəyişdirilmə vaxtı</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
