@@ -32,12 +32,20 @@
         <translation>Hora da modificação:</translation>
     </message>
 </context>
+<context>
+    <name>BestMatchWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="38"/>
+        <source>Best match</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>CustomWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="38"/>
+        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="42"/>
         <source>Custom search</source>
-        <translation type="unfinished"/>
+        <translation>Pesquisa personalizada </translation>
     </message>
 </context>
 <context>
@@ -46,7 +54,7 @@
         <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="57"/>
         <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="100"/>
         <source>Grand Search</source>
-        <translation type="unfinished"/>
+        <translation>Pesquisa geral</translation>
     </message>
     <message>
         <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="163"/>
@@ -119,7 +127,7 @@
 <context>
     <name>GroupWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="254"/>
+        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="260"/>
         <source>More</source>
         <translation>Mais</translation>
     </message>
@@ -129,7 +137,7 @@
     <message>
         <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="67"/>
         <source>Dimensions:</source>
-        <translation type="unfinished"/>
+        <translation>Dimensões:</translation>
     </message>
     <message>
         <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="83"/>
@@ -160,14 +168,6 @@
         <translation>Sem resultados</translation>
     </message>
 </context>
-<context>
-    <name>MatchWidget</name>
-    <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="88"/>
-        <source>Search for &quot;%1&quot;</source>
-        <translation>Buscar por &quot;%1&quot;</translation>
-    </message>
-</context>
 <context>
     <name>PlanWidget</name>
     <message>
@@ -181,27 +181,27 @@
         <translation>Participe do programa de experiência com a busca</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="63"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
         <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
         <translation>Juntar-se ao programa de experiência que você concorda e nos autoriza a coletar informações de seu dispositivo e sistema, arquivos, ícones, conteúdos e propriedades, aplicativos e suas configurações. Se você recusa nossa coleta e uso das informações supracitadas, não se junte ao programa.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="71"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
         <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
         <translation>Para saber mais sobre a gestão de seus dados, por favor consulte a Política de Privacidade de Software UnionTech (</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="75"/>
         <source>https://www.uniontech.com/agreement/privacy-en</source>
         <translation>https://www.uniontech.com/agreement/privacy-en</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="74"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
         <source>https://www.deepin.org/en/agreement/privacy/</source>
         <translation>https://www.deepin.org/en/agreement/privacy/</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="78"/>
         <source>).</source>
         <translation>).</translation>
     </message>
@@ -211,7 +211,7 @@
     <message>
         <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
         <source>Best match</source>
-        <translation type="unfinished"/>
+        <translation>Melhor resultado</translation>
     </message>
     <message>
         <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
@@ -261,7 +261,7 @@
     <message>
         <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="38"/>
         <source>Dimensions:</source>
-        <translation type="unfinished"/>
+        <translation>Dimensões:</translation>
     </message>
     <message>
         <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="39"/>
@@ -291,7 +291,7 @@
     <message>
         <location filename="../src/grand-search-daemon/searcher/file/filesearchutils.cpp" line="215"/>
         <source>modified</source>
-        <translation type="unfinished"/>
+        <translation>modificado</translation>
     </message>
 </context>
 <context>
@@ -302,27 +302,83 @@
         <translation>Conteúdo da busca</translation>
     </message>
 </context>
+<context>
+    <name>SearchEngineWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="48"/>
+        <source>Default search engine</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="56"/>
+        <source>Search for keywords by the default search engine.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
+        <source>Default search engine is</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="81"/>
+        <source>Google</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="82"/>
+        <source>Baidu</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="83"/>
+        <source>Bing</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="84"/>
+        <source>Yahoo</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="85"/>
+        <source>360</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="86"/>
+        <source>Sogou</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>StaticTextWorker</name>
+    <message>
+        <location filename="../src/grand-search-daemon/searcher/web/statictextworker.cpp" line="67"/>
+        <source>Search for &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>TailerWidget</name>
     <message>
         <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="33"/>
         <source>Tailer settings</source>
-        <translation type="unfinished"/>
+        <translation>Configurações de alfaiate</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="42"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
         <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
-        <translation type="unfinished"/>
+        <translation>Isto é exibido ao final dos resultados da pesquisa para melhor identificação e distinção de itens com nomes duplicados.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="50"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="56"/>
         <source>Parent directory</source>
-        <translation type="unfinished"/>
+        <translation>Diretório Parental</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="52"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="58"/>
         <source>Time modified</source>
-        <translation type="unfinished"/>
+        <translation>Hora da modificação</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
