@@ -32,10 +32,18 @@
         <translation>Час внесення змін:</translation>
     </message>
 </context>
+<context>
+    <name>BestMatchWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="38"/>
+        <source>Best match</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>CustomWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="38"/>
+        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="42"/>
         <source>Custom search</source>
         <translation>Нетиповий пошук</translation>
     </message>
@@ -119,7 +127,7 @@
 <context>
     <name>GroupWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="254"/>
+        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="260"/>
         <source>More</source>
         <translation>Більше</translation>
     </message>
@@ -160,14 +168,6 @@
         <translation>Нічого не знайдено</translation>
     </message>
 </context>
-<context>
-    <name>MatchWidget</name>
-    <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="88"/>
-        <source>Search for &quot;%1&quot;</source>
-        <translation>Шукати «%1»</translation>
-    </message>
-</context>
 <context>
     <name>PlanWidget</name>
     <message>
@@ -181,27 +181,27 @@
         <translation>Долучитися до програми відгуків щодо пошуку</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="63"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
         <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
         <translation>Долучення до програми відгуків щодо пошуку означає, що ви надаєте нам дозвіл і уповноважуєте нас збирати відомості щодо вашого пристрою і системи, зокрема піктограм, вмісту та властивостей, програм та їхніх налаштувань. Якщо ви відмовляєте нам у збиранні даних і використанні згаданої вище інформації, не долучайтеся до програми.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="71"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
         <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
         <translation>Щоб дізнатися більше про керування вашими даними, будь ласка, ознайомтеся із правилами конфіденційності щодо програмного забезпечення UnionTech (</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="75"/>
         <source>https://www.uniontech.com/agreement/privacy-en</source>
         <translation>https://www.uniontech.com/agreement/privacy-en</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="74"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
         <source>https://www.deepin.org/en/agreement/privacy/</source>
         <translation>https://www.deepin.org/en/agreement/privacy/</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="78"/>
         <source>).</source>
         <translation>).</translation>
     </message>
@@ -302,6 +302,62 @@
         <translation>Пошук вмісту</translation>
     </message>
 </context>
+<context>
+    <name>SearchEngineWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="48"/>
+        <source>Default search engine</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="56"/>
+        <source>Search for keywords by the default search engine.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
+        <source>Default search engine is</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="81"/>
+        <source>Google</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="82"/>
+        <source>Baidu</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="83"/>
+        <source>Bing</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="84"/>
+        <source>Yahoo</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="85"/>
+        <source>360</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="86"/>
+        <source>Sogou</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>StaticTextWorker</name>
+    <message>
+        <location filename="../src/grand-search-daemon/searcher/web/statictextworker.cpp" line="67"/>
+        <source>Search for &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>TailerWidget</name>
     <message>
@@ -310,17 +366,17 @@
         <translation>Параметри хвостовика</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="42"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
         <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
         <translation>Його буде показано наприкінці результатів пошуку для поліпшення ідентифікації та розрізнення записів із дубльованими назвами.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="50"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="56"/>
         <source>Parent directory</source>
         <translation>Батьківський каталог</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="52"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="58"/>
         <source>Time modified</source>
         <translation>Час зміни</translation>
     </message>
